say

package
v0.0.0-...-6d97f1a Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Sep 12, 2018 License: Apache-2.0 Imports: 2 Imported by: 0

Documentation

Index

Constants

const (
	DefaultLanguage = "en"
	DefaultVoice    = "alex"
)

Variables

This section is empty.

Functions

This section is empty.

Types

type SaySpeaker

type SaySpeaker struct {
	Language string
	VoiceID  string
}

func New

func New(language, voiceName string) *SaySpeaker

New takes in a language and voice to create a SaySpeaker instance

func (*SaySpeaker) GenerateSpeech

func (ss *SaySpeaker) GenerateSpeech(text, fileName string) error

GenerateSpeech takes in a string and outputs Synthesized Speech and possibly an error.

Jump to