Documentation
¶
Index ¶
Constants ¶
const ( DefaultLanguage = "en" DefaultVoice = "alex" )
Variables ¶
This section is empty.
Functions ¶
This section is empty.
Types ¶
type SaySpeaker ¶
func New ¶
func New(language, voiceName string) *SaySpeaker
New takes in a language and voice to create a SaySpeaker instance
func (*SaySpeaker) GenerateSpeech ¶
func (ss *SaySpeaker) GenerateSpeech(text, fileName string) error
GenerateSpeech takes in a string and outputs Synthesized Speech and possibly an error.
Click to show internal directories.
Click to hide internal directories.